@@ -26,7 +26,9 @@
 #include <menu-cache.h>
 
 static GtkWidget* win = NULL; /* the run dialog */
+static MenuCache* menu_cache = NULL;
 static GSList* app_list = NULL; /* all known apps in menu cache */
+static gpointer reload_notify_id = NULL;
 
 typedef struct _ThreadData
 {
@@ -55,6 +57,8 @@ static MenuCacheApp* match_app_by_exec(const char* exec)
     {
         MenuCacheApp* app = MENU_CACHE_APP(l->data);
         const char* app_exec = menu_cache_app_get_exec(app);
+        if ( ! app_exec)
+            continue;
 #if 0   /* This is useless and incorrect. */
         /* Dirty hacks to skip sudo programs. This can be a little bit buggy */
         if( g_str_has_prefix(app_exec, "gksu") )
@@ -235,6 +239,17 @@ static void setup_auto_complete( GtkEntry* entry )
     }
 }
 
+static void reload_apps(MenuCache* cache, gpointer user_data)
+{
+    g_debug("reload apps!");
+    if(app_list)
+    {
+        g_slist_foreach(app_list, (GFunc)menu_cache_item_unref, NULL);
+        g_slist_free(app_list);
+    }
+    app_list = (GSList*)menu_cache_list_all_apps(cache);
+}
+
 static void on_response( GtkDialog* dlg, gint response, gpointer user_data )
 {
     GtkEntry* entry = (GtkEntry*)user_data;
@@ -261,6 +276,12 @@ static void on_response( GtkDialog* dlg, gint response, gpointer user_data )
     g_slist_foreach(app_list, (GFunc)menu_cache_item_unref, NULL);
     g_slist_free(app_list);
     app_list = NULL;
+
+    /* free menu cache */
+    menu_cache_remove_reload_notify(menu_cache, reload_notify_id);
+    reload_notify_id = NULL;
+    menu_cache_unref(menu_cache);
+    menu_cache = NULL;
 }
 
 static void on_entry_changed( GtkEntry* entry, GtkImage* img )
@@ -288,7 +309,6 @@ static void on_entry_changed( GtkEntry* entry, GtkImage* img )
 void gtk_run()
 {
     GtkWidget *entry, *hbox, *img;
-    MenuCache* menu_cache;
 
     if( win )
     {
@@ -333,7 +353,7 @@ void gtk_run()
     if( menu_cache )
     {
         app_list = (GSList*)menu_cache_list_all_apps(menu_cache);
-        menu_cache_unref(menu_cache);
+        reload_notify_id = menu_cache_add_reload_notify(menu_cache, reload_apps, NULL);
     }
 }
 
